nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Ctl

Struct Ctl 

#[repr(transparent)]
pub struct Ctl(pub u32);
USART Control register. USART control settings that are more likely to change during operation.

Tuple Fields

0: u32

Implementations

Source

impl Ctl

pub const fn txbrken(&self) -> Txbrken

Break Enable.

pub const fn set_txbrken(&mut self, val: Txbrken)

Break Enable.

pub const fn addrdet(&self) -> bool

Enable address detect mode.

pub const fn set_addrdet(&mut self, val: bool)

Enable address detect mode.

pub const fn txdis(&self) -> Txdis

Transmit Disable.

pub const fn set_txdis(&mut self, val: Txdis)

Transmit Disable.

pub const fn cc(&self) -> Cc

Continuous Clock generation. By default, SCLK is only output while data is being transmitted in synchronous mode.

pub const fn set_cc(&mut self, val: Cc)

Continuous Clock generation. By default, SCLK is only output while data is being transmitted in synchronous mode.

pub const fn clrcconrx(&self) -> Clrcconrx

Clear Continuous Clock.

pub const fn set_clrcconrx(&mut self, val: Clrcconrx)

Clear Continuous Clock.

pub const fn autobaud(&self) -> bool

Autobaud enable.

pub const fn set_autobaud(&mut self, val: bool)

Autobaud enable.