nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Fifordnopop

Struct Fifordnopop 

#[repr(transparent)]
pub struct Fifordnopop(pub u32);
FIFO data read with no FIFO pop.

Tuple Fields

0: u32

Implementations

Source

impl Fifordnopop

pub const fn rxdata(&self) -> u16

Received data from the FIFO. The number of bits used depends on the DATALEN and PARITYSEL settings.

pub const fn set_rxdata(&mut self, val: u16)

Received data from the FIFO. The number of bits used depends on the DATALEN and PARITYSEL settings.

pub const fn framerr(&self) -> bool

Framing Error status flag. This bit reflects the status for the data it is read along with from the FIFO, and indicates that the character was received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.

pub const fn set_framerr(&mut self, val: bool)

Framing Error status flag. This bit reflects the status for the data it is read along with from the FIFO, and indicates that the character was received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.

pub const fn parityerr(&self) -> bool

Parity Error status flag. This bit reflects the status for the data it is read along with from the FIFO. This bit will be set when a parity error is detected in a received character.

pub const fn set_parityerr(&mut self, val: bool)

Parity Error status flag. This bit reflects the status for the data it is read along with from the FIFO. This bit will be set when a parity error is detected in a received character.

pub const fn rxnoise(&self) -> bool

Received Noise flag. See description of the RxNoiseInt bit in Table 354.

pub const fn set_rxnoise(&mut self, val: bool)

Received Noise flag. See description of the RxNoiseInt bit in Table 354.