#[repr(transparent)]pub struct Intenset(pub u32);Expand description
Interrupt Enable read and Set register for USART (not FIFO) status. Contains individual interrupt enable bits for each potential USART interrupt. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.
Tuple Fields
0: u32Implementations
Sourceimpl Intenset
impl Intenset
Sourcepub const fn txidleen(&self) -> bool
pub const fn txidleen(&self) -> bool
When 1, enables an interrupt when the transmitter becomes idle (TXIDLE = 1).
Sourcepub const fn set_txidleen(&mut self, val: bool)
pub const fn set_txidleen(&mut self, val: bool)
When 1, enables an interrupt when the transmitter becomes idle (TXIDLE = 1).
Sourcepub const fn deltactsen(&self) -> bool
pub const fn deltactsen(&self) -> bool
When 1, enables an interrupt when there is a change in the state of the CTS input.
Sourcepub const fn set_deltactsen(&mut self, val: bool)
pub const fn set_deltactsen(&mut self, val: bool)
When 1, enables an interrupt when there is a change in the state of the CTS input.
Sourcepub const fn txdisen(&self) -> bool
pub const fn txdisen(&self) -> bool
When 1, enables an interrupt when the transmitter is fully disabled as indicated by the TXDISINT flag in STAT. See description of the TXDISINT bit for details.
Sourcepub const fn set_txdisen(&mut self, val: bool)
pub const fn set_txdisen(&mut self, val: bool)
When 1, enables an interrupt when the transmitter is fully disabled as indicated by the TXDISINT flag in STAT. See description of the TXDISINT bit for details.
Sourcepub const fn deltarxbrken(&self) -> bool
pub const fn deltarxbrken(&self) -> bool
When 1, enables an interrupt when a change of state has occurred in the detection of a received break condition (break condition asserted or deasserted).
Sourcepub const fn set_deltarxbrken(&mut self, val: bool)
pub const fn set_deltarxbrken(&mut self, val: bool)
When 1, enables an interrupt when a change of state has occurred in the detection of a received break condition (break condition asserted or deasserted).
Sourcepub const fn starten(&self) -> bool
pub const fn starten(&self) -> bool
When 1, enables an interrupt when a received start bit has been detected.
Sourcepub const fn set_starten(&mut self, val: bool)
pub const fn set_starten(&mut self, val: bool)
When 1, enables an interrupt when a received start bit has been detected.
Sourcepub const fn framerren(&self) -> bool
pub const fn framerren(&self) -> bool
When 1, enables an interrupt when a framing error has been detected.
Sourcepub const fn set_framerren(&mut self, val: bool)
pub const fn set_framerren(&mut self, val: bool)
When 1, enables an interrupt when a framing error has been detected.
Sourcepub const fn parityerren(&self) -> bool
pub const fn parityerren(&self) -> bool
When 1, enables an interrupt when a parity error has been detected.
Sourcepub const fn set_parityerren(&mut self, val: bool)
pub const fn set_parityerren(&mut self, val: bool)
When 1, enables an interrupt when a parity error has been detected.
Sourcepub const fn rxnoiseen(&self) -> bool
pub const fn rxnoiseen(&self) -> bool
When 1, enables an interrupt when noise is detected. See description of the RXNOISEINT bit in Table 354.
Sourcepub const fn set_rxnoiseen(&mut self, val: bool)
pub const fn set_rxnoiseen(&mut self, val: bool)
When 1, enables an interrupt when noise is detected. See description of the RXNOISEINT bit in Table 354.
Sourcepub const fn aberren(&self) -> bool
pub const fn aberren(&self) -> bool
When 1, enables an interrupt when an auto baud error occurs.
Sourcepub const fn set_aberren(&mut self, val: bool)
pub const fn set_aberren(&mut self, val: bool)
When 1, enables an interrupt when an auto baud error occurs.