nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intstat

Struct Intstat 

#[repr(transparent)]
pub struct Intstat(pub u32);
Interrupt status register. Reflects interrupts that are currently enabled.

Tuple Fields

0: u32

Implementations

Source

impl Intstat

pub const fn txidle(&self) -> bool

Transmitter Idle status.

pub const fn set_txidle(&mut self, val: bool)

Transmitter Idle status.

pub const fn deltacts(&self) -> bool

This bit is set when a change in the state of the CTS input is detected.

pub const fn set_deltacts(&mut self, val: bool)

This bit is set when a change in the state of the CTS input is detected.

pub const fn txdisint(&self) -> bool

Transmitter Disabled Interrupt flag.

pub const fn set_txdisint(&mut self, val: bool)

Transmitter Disabled Interrupt flag.

pub const fn deltarxbrk(&self) -> bool

This bit is set when a change in the state of receiver break detection occurs.

pub const fn set_deltarxbrk(&mut self, val: bool)

This bit is set when a change in the state of receiver break detection occurs.

pub const fn start(&self) -> bool

This bit is set when a start is detected on the receiver input.

pub const fn set_start(&mut self, val: bool)

This bit is set when a start is detected on the receiver input.

pub const fn framerrint(&self) -> bool

Framing Error interrupt flag.

pub const fn set_framerrint(&mut self, val: bool)

Framing Error interrupt flag.

pub const fn parityerrint(&self) -> bool

Parity Error interrupt flag.

pub const fn set_parityerrint(&mut self, val: bool)

Parity Error interrupt flag.

pub const fn rxnoiseint(&self) -> bool

Received Noise interrupt flag.

pub const fn set_rxnoiseint(&mut self, val: bool)

Received Noise interrupt flag.

pub const fn aberrint(&self) -> bool

Auto baud Error Interrupt flag.

pub const fn set_aberrint(&mut self, val: bool)

Auto baud Error Interrupt flag.