#[repr(transparent)]pub struct Osr(pub u32);Expand description
Oversample selection register for asynchronous communication.
Tuple Fields
0: u32Implementations
Sourceimpl Osr
impl Osr
Sourcepub const fn osrval(&self) -> u8
pub const fn osrval(&self) -> u8
Oversample Selection Value. 0 to 3 = not supported 0x4 = 5 function clocks are used to transmit and receive each data bit. 0x5 = 6 function clocks are used to transmit and receive each data bit. 0xF= 16 function clocks are used to transmit and receive each data bit.
Sourcepub const fn set_osrval(&mut self, val: u8)
pub const fn set_osrval(&mut self, val: u8)
Oversample Selection Value. 0 to 3 = not supported 0x4 = 5 function clocks are used to transmit and receive each data bit. 0x5 = 6 function clocks are used to transmit and receive each data bit. 0xF= 16 function clocks are used to transmit and receive each data bit.