#[repr(transparent)]pub struct Brg(pub u32);Expand description
Baud Rate Generator register. 16-bit integer baud rate divisor value.
Tuple Fields
0: u32Implementations
Sourceimpl Brg
impl Brg
Sourcepub const fn brgval(&self) -> u16
pub const fn brgval(&self) -> u16
This value is used to divide the USART input clock to determine the baud rate, based on the input clock from the FRG. 0 = FCLK is used directly by the USART function. 1 = FCLK is divided by 2 before use by the USART function. 2 = FCLK is divided by 3 before use by the USART function. 0xFFFF = FCLK is divided by 65,536 before use by the USART function.
Sourcepub const fn set_brgval(&mut self, val: u16)
pub const fn set_brgval(&mut self, val: u16)
This value is used to divide the USART input clock to determine the baud rate, based on the input clock from the FRG. 0 = FCLK is used directly by the USART function. 1 = FCLK is divided by 2 before use by the USART function. 2 = FCLK is divided by 3 before use by the USART function. 0xFFFF = FCLK is divided by 65,536 before use by the USART function.